<template>
  <BaseChart v-slot="{ options }">
    <PolarAreaChart
      :data="chartData"
      :options="options"
    />
  </BaseChart>
  <div class="flex w-full flex-wrap justify-center gap-3 py-3">
    <template
      v-for="(item, index) in labels"
      :key="index"
    >
      <div class="flex items-center">
        <div
          :style="{ borderColor: value.colors[index] }"
          class="mr-1 size-2.5 rounded-full border-2"
        />
        <div class="text-sm text-gray-600">{{ item }}</div>
      </div>
    </template>
  </div>
</template>

<script lang="ts" setup>
import { PolarArea as PolarAreaChart } from "vue-chartjs";
import { type ChartData } from "chart.js";
import { transparentize } from "color2k";
import BaseChart from "@/js/contexts/shared/ui/components/charts/BaseChart.vue";

const props = defineProps<{
  value: DataSet;
  labels: string[];
  label: string;
}>();

const { t } = useI18n();

export type DataSet = {
  values: number[];
  colors: string[];
};

const chartData = computed(() => {
  return {
    labels: props.labels ?? [],
    datasets: [
      {
        data: props.value.values ?? [],
        label: t(props.label),
        borderColor: props.value.colors,
        backgroundColor: props.value.colors.map((color) => transparentize(color, 0.7)),
        borderWidth: 2,
      },
    ],
  } satisfies ChartData<"polarArea">;
});
</script>
